@@ -11,11 +11,22 @@
 
 from .utils import dumps_list
 from .base_classes import BaseLaTeXContainer
+from .package import Package
 
 from collections import Counter
 import re
 
 
+def get_table_width(table_spec):
+    column_letters = ['l', 'c', 'r', 'p', 'm', 'b']
+
+    # Remove things like {\bfseries}
+    cleaner_spec = re.sub(r'{[^}]*}', '', table_spec)
+    spec_counter = Counter(cleaner_spec)
+
+    return sum(spec_counter[l] for l in column_letters)
+
+
 class Table(BaseLaTeXContainer):
 
     """A class that represents a table."""
@@ -24,13 +35,7 @@ class Table(BaseLaTeXContainer):
         self.table_spec = table_spec
         self.pos = pos
 
-        column_letters = ['l', 'c', 'r', 'p', 'm', 'b']
-
-        # Remove things like {\bfseries}
-        cleaner_spec = re.sub(r'{[^}]*}', '', table_spec)
-        spec_counter = Counter(cleaner_spec)
-
-        self.width = sum(spec_counter[l] for l in column_letters)
+        self.width = get_table_width(table_spec)
 
         super().__init__(data)
 
@@ -53,6 +58,33 @@ class Table(BaseLaTeXContainer):
         """Add a row of cells to the table"""
         self.append(dumps_list(cells, escape=escape, token='&') + r'\\')
 
+    def add_multicolumn(self, size, align, content, cells=None, escape=False):
+        """
+        Add a multicolumn of width size to the table, with cell content content
+        """
+        self.append(r'\multicolumn{%d}{%s}{%s}' % (size, align, content))
+        if cells is not None:
+            self.add_row(cells)
+        else:
+            self.append(r'\\')
+
+    def add_multirow(self, size, align, content, hlines=True, cells=None,
+                     escape=False):
+        """
+        Add a multirow of height size to the table, with cell content content
+        """
+        self.append(r'\multirow{%d}{%s}{%s}' % (size, align, content))
+        self.packages.add(Package('multirow'))
+        if cells is not None:
+            for i, row in enumerate(cells):
+                if hlines and i:
+                    self.add_hline(2)
+                self.append('&')
+                self.add_row(row)
+        else:
+            for i in range(size):
+                self.add_empty_row()
+
     def dumps(self):
         """Represents the document as a string in LaTeX syntax."""
         string = r'\begin{tabular}'
